==> ukui-biometric-auth_1.0.3.orig.tar.gz: ukui-biometric-auth/polkit-agent/i18n_ts/ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>MainWindow</name>
    <message>
        <source>Form</source>
        <translation>форма</translation>
    </message>
    <message>
        <source>Biometric</source>
        <translation>Биометрические</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Детали</translation>
    </message>
    <message>
        <source>Polkit.subject-pid:</source>
        <translation>Polkit.subject-PID:</translation>
    </message>
    <message>
        <source>Vendor:</source>
        <translation>Производитель:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Описание:</translation>
    </message>
    <message>
        <source>Polkit.caller-pid:</source>
        <translation>Polkit.caller-PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Действие:</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Authenticate</source>
        <translation>проверять подлинность</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Аутентификация</translation>
    </message>
    <message>
        <source>in authentication, please wait...</source>
        <translation>в аутентификации, пожалуйста, подождите ...</translation>
    </message>
    <message>
        <source>An application is attempting to perform an action that requires privileges. Authentication is required to perform this action.</source>
        <translation>Приложение пытается выполнить действие, требующее привилегий. Для выполнения этого действия требуется аутентификация.</translation>
    </message>
    <message>
        <source>Password: </source>
        <translation>Пароль: </translation>
    </message>
    <message>
        <source>Authentication failed, please try again.</source>
        <translation>Ошибка аутентификации. Пожалуйста, попробуйте еще раз.</translation>
    </message>
</context>
<context>
    <name>PolkitListener</name>
    <message>
        <source>Another client is already authenticating, please try again later.</source>
        <translation>Другой клиент уже аутентифицируется, повторите попытку позже.</translation>
    </message>
    <message>
        <source>Authentication failure, please try again.</source>
        <translation>Ошибка аутентификации, повторите попытку.</translation>
    </message>
</context>
</TS>

==> ukui-biometric-auth_1.2.1.orig.tar.gz: ukui-biometric-auth/polkit-agent/i18n_ts/ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru">
<context>
    <name>MainWindow</name>
    <message>
        <source>Form</source>
        <translation>форма</translation>
    </message>
    <message>
        <source>Biometric</source>
        <translation>Биометрические</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Детали</translation>
    </message>
    <message>
        <source>Polkit.subject-pid:</source>
        <translation>Polkit.subject-PID:</translation>
    </message>
    <message>
        <source>Vendor:</source>
        <translation>Производитель:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Описание:</translation>
    </message>
    <message>
        <source>Polkit.caller-pid:</source>
        <translation>Polkit.caller-PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Действие:</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Authenticate</source>
        <translation>проверять подлинность</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Аутентификация</translation>
    </message>
    <message>
        <source>in authentication, please wait...</source>
        <translation>в аутентификации, пожалуйста, подождите ...</translation>
    </message>
    <message>
        <source>An application is attempting to perform an action that requires privileges. Authentication is required to perform this action.</source>
        <translation>Приложение пытается выполнить действие, требующее привилегий. Для выполнения этого действия требуется аутентификация.</translation>
    </message>
    <message>
        <source>Password: </source>
        <translation>Пароль: </translation>
    </message>
    <message>
        <source>Authentication failed, please try again.</source>
        <translation>Ошибка аутентификации. Пожалуйста, попробуйте еще раз.</translation>
    </message>
</context>
<context>
    <name>PolkitListener</name>
    <message>
        <source>Another client is already authenticating, please try again later.</source>
        <translation>Другой клиент уже аутентифицируется, повторите попытку позже.</translation>
    </message>
    <message>
        <source>Authentication failure, please try again.</source>
        <translation>Ошибка аутентификации, повторите попытку.</translation>
    </message>
    <message>
        <source>Account locked %1 minutes due to %2 fail attempts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Authentication failure,there are still %1 remaining opportunities</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
